@@ -541,7 +541,7 @@ boolean do_effect(lives_rfx_t *rfx, boolean is_preview) {
       
       init_clipboard();
       
-      lives_memcpy(clipboard,cfile,sizeof(file));
+      lives_memcpy(clipboard,cfile,sizeof(lives_clip_t));
       cfile->is_loaded=TRUE;
       mainw->suppress_dprint=TRUE;
       mainw->only_close=TRUE;
@@ -630,7 +630,7 @@ lives_render_error_t realfx_progress (boolean reset) {
 
     if (cfile->clip_type==CLIP_TYPE_FILE) {
       if (cfile->frame_index_back!=NULL) g_free(cfile->frame_index_back);
-      cfile->frame_index_back=frame_index_copy(cfile->frame_index,cfile->frames);
+      cfile->frame_index_back=frame_index_copy(cfile->frame_index,cfile->frames,0);
     }
     write_error=LIVES_RENDER_ERROR_NONE;
     return LIVES_RENDER_READY;
@@ -759,7 +759,7 @@ boolean on_realfx_activate_inner(int type, lives_rfx_t *rfx) {
 
   apply_audio_fx=FALSE;
 
-  if (type==0&&((cfile->achans>0&&prefs->audio_src==AUDIO_SRC_INT&&has_audio_filters(FALSE))||mainw->agen_key!=0)) {
+  if (type==0&&((cfile->achans>0&&prefs->audio_src==AUDIO_SRC_INT&&has_audio_filters(AF_TYPE_ANY))||mainw->agen_key!=0)) {
     if (mainw->agen_key!=0&&cfile->achans==0) {
       // apply audio gen to clip with no audio - prompt for audio settings
       resaudw=create_resaudw(2,NULL,NULL);
@@ -994,7 +994,7 @@ void deinterlace_frame(weed_plant_t *layer, weed_timecode_t tc) {
 
 
 weed_plant_t *get_blend_layer(weed_timecode_t tc) {
-  file *blend_file;
+  lives_clip_t *blend_file;
   static weed_timecode_t blend_tc=0;
   weed_timecode_t ntc=tc;
 
@@ -1094,7 +1094,7 @@ boolean rte_on_off_callback (GtkAccelGroup *group, GObject *obj, guint keyval, G
   }
 
   if (mainw->playing_file==-1&&mainw->current_file>0&&((has_video_filters(FALSE)&&!has_video_filters(TRUE))||
-						       (cfile->achans>0&&prefs->audio_src==AUDIO_SRC_INT&&has_audio_filters(FALSE))||
+						       (cfile->achans>0&&prefs->audio_src==AUDIO_SRC_INT&&has_audio_filters(AF_TYPE_ANY))||
 						       mainw->agen_key!=0)) {
 
     lives_widget_set_sensitive(mainw->rendered_fx[0].menuitem,TRUE);
