@@ -11,6 +11,7 @@
 #ifdef ENABLE_JACK
 #include "callbacks.h"
 #include "support.h"
+#include "effects.h"
 #include "effects-weed.h"
 
 #define afile mainw->files[jackd->playing_file]
@@ -394,7 +395,7 @@ static int audio_process (nframes_t nframes, void *arg) {
     gfloat shrink_factor=1.f;
     double vol;
 
-    file *xfile=afile;
+    lives_clip_t *xfile=afile;
 
 #ifdef DEBUG_AJACK
     g_printerr("playing... jackFramesAvailable = %ld\n", jackFramesAvailable);
@@ -621,7 +622,7 @@ static int audio_process (nframes_t nframes, void *arg) {
 		}
 	      }
 
-	      if (!pl_error&&has_audio_filters(FALSE)) {
+	      if (!pl_error&&has_audio_filters(AF_TYPE_ANY)) {
 		uint64_t tc=jackd->audio_ticks+(uint64_t)(jackd->frames_written/(double)jackd->sample_out_rate*U_SEC);
 	       // apply any audio effects with in_channels
 		weed_apply_audio_effects_rt(out_buffer,jackd->num_output_channels,numFramesToWrite,jackd->sample_out_rate,tc,FALSE);
@@ -644,7 +645,7 @@ static int audio_process (nframes_t nframes, void *arg) {
 				      jackd->num_output_channels, afile->signed_endian&AFORM_UNSIGNED, FALSE, vol);
 	      }
 
-	      if (has_audio_filters(FALSE)&&jackd->playing_file!=mainw->ascrap_file) {
+	      if (has_audio_filters(AF_TYPE_ANY)&&jackd->playing_file!=mainw->ascrap_file) {
 		uint64_t tc=jackd->audio_ticks+(uint64_t)(jackd->frames_written/(double)jackd->sample_out_rate*U_SEC);
 	       // apply any audio effects with in_channels
 		weed_apply_audio_effects_rt(out_buffer,jackd->num_output_channels,numFramesToWrite,jackd->sample_out_rate,tc,FALSE);
@@ -914,7 +915,7 @@ static size_t audio_read_inner(jack_driver_t *jackd, float **in_buffer, int ofil
 
   void *holding_buff=g_try_malloc(rbytes);
 
-  file *ofile=mainw->files[ofileno];
+  lives_clip_t *ofile=mainw->files[ofileno];
 
   size_t bytes=0;
 
@@ -975,7 +976,7 @@ static int audio_read (nframes_t nframes, void *arg) {
     // in this case we read external audio, but maybe not record it
     // we may wish to analyse the audio for example
 
-    if (has_audio_filters(TRUE)) {
+    if (has_audio_filters(AF_TYPE_A)) {
 	uint64_t tc=jackd->audio_ticks+(uint64_t)(jackd->frames_written/(double)jackd->sample_in_rate*U_SEC);
 	// apply any audio effects with in_channels and no out_channels
 	weed_apply_audio_effects_rt(in_buffer,jackd->num_input_channels,nframes,jackd->sample_in_rate,tc,TRUE);
@@ -1696,7 +1697,7 @@ void jack_aud_pb_ready(int fileno) {
 
   // called at pb start and rec stop (after rec_ext_audio)
   gchar *tmpfilename=NULL;
-  file *sfile=mainw->files[fileno];
+  lives_clip_t *sfile=mainw->files[fileno];
   int asigned=!(sfile->signed_endian&AFORM_UNSIGNED);
   int aendian=!(sfile->signed_endian&AFORM_BIG_ENDIAN);
 
